@@ -14,67 +14,75 @@ module FoodCritic
         cookbook_paths: [],
         role_paths: [],
         environment_paths: [],
-        exclude_paths: []
+        exclude_paths: [],
       }
       @parser = OptionParser.new do |opts|
-        opts.banner = 'foodcritic [cookbook_paths]'
-        opts.on('-t', '--tags TAGS',
-                'Check against (or exclude ~) rules with the '\
-                'specified tags.') do |t|
+        opts.banner = "foodcritic [cookbook_paths]"
+        opts.on("-t", "--tags TAGS",
+                "Check against (or exclude ~) rules with the "\
+                "specified tags.") do |t|
           @options[:tags] << t
         end
-        opts.on('-f', '--epic-fail TAGS',
+        opts.on("-l", "--list",
+                "List all enabled rules and their descriptions.") do |t|
+          @options[:list] = t
+        end
+        opts.on("-f", "--epic-fail TAGS",
                 "Fail the build based on tags. Use 'any' to fail "\
-                'on all warnings.') do |t|
+                "on all warnings.") do |t|
           @options[:fail_tags] << t
         end
-        opts.on('-c', '--chef-version VERSION',
-                'Only check against rules valid for this version '\
-                'of Chef.') do |c|
+        opts.on("-c", "--chef-version VERSION",
+                "Only check against rules valid for this version "\
+                "of Chef.") do |c|
           @options[:chef_version] = c
         end
-        opts.on('-B', '--cookbook-path PATH',
-                'Cookbook path(s) to check.') do |b|
+        opts.on("-B", "--cookbook-path PATH",
+                "Cookbook path(s) to check.") do |b|
           @options[:cookbook_paths] << b
         end
-        opts.on('-C', '--[no-]context',
-                'Show lines matched against rather than the '\
-                'default summary.') do |c|
+        opts.on("-C", "--[no-]context",
+                "Show lines matched against rather than the "\
+                "default summary.") do |c|
           @options[:context] = c
         end
-        opts.on('-E', '--environment-path PATH',
-                'Environment path(s) to check.') do |e|
+        opts.on("-E", "--environment-path PATH",
+                "Environment path(s) to check.") do |e|
           @options[:environment_paths] << e
         end
-        opts.on('-I', '--include PATH',
-                'Additional rule file path(s) to load.') do |i|
+        opts.on("-I", "--include PATH",
+                "Additional rule file path(s) to load.") do |i|
           @options[:include_rules] << i
         end
-        opts.on('-G', '--search-gems',
-                'Search rubygems for rule files with the path '\
-                'foodcritic/rules/**/*.rb') do |g|
+        opts.on("-G", "--search-gems",
+                "Search rubygems for rule files with the path "\
+                "foodcritic/rules/**/*.rb") do |g|
           @options[:search_gems] = true
         end
-        opts.on('-R', '--role-path PATH',
-                'Role path(s) to check.') do |r|
+        opts.on("-P", "--progress",
+                "Show progress of files being checked") do
+          @options[:progress] = true
+        end
+        opts.on("-R", "--role-path PATH",
+                "Role path(s) to check.") do |r|
           @options[:role_paths] << r
         end
-        opts.on('-S', '--search-grammar PATH',
-                'Specify grammar to use when validating search syntax.') do |s|
+        opts.on("-S", "--search-grammar PATH",
+                "Specify grammar to use when validating search syntax.") do |s|
           @options[:search_grammar] = s
         end
-        opts.on('-V', '--version',
-                'Display the foodcritic version.') do |v|
+        opts.on("-V", "--version",
+                "Display the foodcritic version.") do |v|
           @options[:version] = true
         end
-        opts.on('-X', '--exclude PATH',
-                'Exclude path(s) from being linted.') do |e|
+        opts.on("-X", "--exclude PATH",
+                "Exclude path(s) from being linted. PATH is relative to the cookbook, not an absolute PATH") do |e|
           options[:exclude_paths] << e
         end
       end
       # -v is not implemented but OptionParser gives the Foodcritic's version
       # if that flag is passed
-      if args.include? '-v'
+      if args.include? "-v"
         help
       else
         begin
@@ -89,7 +97,7 @@ module FoodCritic
     #
     # @return [Boolean] True if help should be shown.
     def show_help?
-      @args.length == 1 && @args.first == '--help'
+      @args.length == 1 && @args.first == "--help"
     end
 
     # The help text.
@@ -106,6 +114,13 @@ module FoodCritic
       @options.key?(:version)
     end
 
+    # Just list enabled rules, don't actually run a lint check?
+    #
+    # @return [Boolean] True if a rule listing is requested.
+    def list_rules?
+      @options.key?(:list)
+    end
+
     # The version string.
     #
     # @return [String] Current installed version.
